@@ -15,6 +15,7 @@
 import warnings
 
 import debtcollector
+from debtcollector.fixtures import disable
 from debtcollector import moves
 from debtcollector import removals
 from debtcollector import renames
@@ -66,6 +67,17 @@ class KittyKat(object):
         return 'supermeow'
 
 
+class Giraffe(object):
+    color = 'orange'
+    colour = moves.moved_read_only_property('colour', 'color')
+
+    @property
+    def height(self):
+        return 2
+
+    heightt = moves.moved_read_only_property('heightt', 'height')
+
+
 class NewHotness(object):
     def hot(self):
         return 'cold'
@@ -114,6 +126,22 @@ class ThingB(object):
     def black_tristars(self):
         pass
 
+    @removals.removed_property
+    def green_tristars(self):
+        return 'green'
+
+    @green_tristars.setter
+    def green_tristars(self, value):
+        pass
+
+    @green_tristars.deleter
+    def green_tristars(self):
+        pass
+
+    @removals.removed_property(message="stop using me")
+    def green_blue_tristars(self):
+        return 'green-blue'
+
     @removals.remove(category=PendingDeprecationWarning)
     def blue_tristars(self):
         pass
@@ -199,6 +227,14 @@ class MovedPropertyTest(test_base.TestCase):
         self.assertEqual('woof', dog.burk)
         self.assertEqual('woof', dog.bark)
 
+    def test_readonly_move(self):
+        with warnings.catch_warnings(record=True) as capture:
+            warnings.simplefilter("always")
+            self.assertEqual('orange', Giraffe.colour)
+            g = Giraffe()
+            self.assertEqual(2, g.heightt)
+        self.assertEqual(2, len(capture))
+
     def test_warnings_emitted(self):
         dog = WoofWoof()
         with warnings.catch_warnings(record=True) as capture:
@@ -225,6 +261,19 @@ class MovedPropertyTest(test_base.TestCase):
         self.assertEqual(0, len(capture))
 
 
+class DisabledTest(test_base.TestCase):
+    def test_basics(self):
+        dog = WoofWoof()
+        c = KittyKat()
+        with warnings.catch_warnings(record=True) as capture:
+            warnings.simplefilter("always")
+            with disable.DisableFixture():
+                self.assertTrue(yellowish_sun())
+                self.assertEqual('woof', dog.berk)
+                self.assertEqual('supermeow', c.meow())
+        self.assertEqual(0, len(capture))
+
+
 class MovedFunctionTest(test_base.TestCase):
     def test_basics(self):
         self.assertTrue(yellowish_sun())
@@ -357,6 +406,27 @@ class RemovalTests(test_base.TestCase):
             self.assertEqual(2, f())
         self.assertEqual(0, len(capture))
 
+    def test_warnings_emitted_property(self):
+        with warnings.catch_warnings(record=True) as capture:
+            warnings.simplefilter("always")
+            o = ThingB()
+            self.assertEqual('green', o.green_tristars)
+            o.green_tristars = 'b'
+            del o.green_tristars
+        self.assertEqual(3, len(capture))
+        w = capture[0]
+        self.assertEqual(DeprecationWarning, w.category)
+
+    def test_warnings_emitted_property_custom_message(self):
+        with warnings.catch_warnings(record=True) as capture:
+            warnings.simplefilter("always")
+            o = ThingB()
+            self.assertEqual('green-blue', o.green_blue_tristars)
+        self.assertEqual(1, len(capture))
+        w = capture[0]
+        self.assertIn('stop using me', str(w.message))
+        self.assertEqual(DeprecationWarning, w.category)
+
     def test_warnings_emitted_function_args(self):
         with warnings.catch_warnings(record=True) as capture:
             warnings.simplefilter("always")
